@@ -83,9 +83,5 @@ class Api(object):
     def delete_performance_result(self, group_key):
         return self.db_client.benchmark_resource.delete_test_group(group_key)
 
-
-
-# if __name__ == '__main__':
-#     API = Api()
-#     b = API.delete_performance_result("20191024160946_vbCVqWSR0L")
-#     pass
+    def add_project_name(self, project_name):
+        return self.db_client.benchmark_resource.add_project_name(project_name)
